@@ -119,6 +119,8 @@ class VIPhreeqc(object):
                            [c_int, c_int, ctypes.c_char_p], ctypes.c_double),
                           ('_get_total_element', phreeqc.GetTotalElement,
                            [c_int, c_int, ctypes.c_char_p], ctypes.c_double),
+                          ('_get_total_ion', phreeqc.GetTotalIon,
+                           [c_int, c_int, ctypes.c_char_p], ctypes.c_double),
                           ('_get_moles', phreeqc.GetMoles,
                            [c_int, c_int, ctypes.c_char_p], ctypes.c_double),
                           ('_get_activity', phreeqc.GetActivity,
@@ -308,6 +310,8 @@ class VIPhreeqc(object):
         return self._get_total(self.id_, solution, bytes(element, 'utf-8'))
     def get_total_element(self, solution, element):
         return self._get_total_element(self.id_, solution, bytes(element, 'utf-8'))
+    def get_total_ion(self, solution, ion):
+        return self._get_total_ion(self.id_, solution, bytes(ion, 'utf-8'))
     def get_moles(self, solution, species):
         return self._get_moles(self.id_, solution, bytes(species, 'utf-8'))
     def get_activity(self, solution, species):
@@ -351,12 +355,12 @@ class VIPhreeqc(object):
         for specie, masters in species_dict.items():
             for master in masters:
                 masters_list.setdefault(master,[]).append(specie)
-            
+
         return masters_list
 
     def get_solution_list(self):
         solution_list = self._get_solution_list(self.id_).decode('utf-8').split(",")
-        return list(map(int, solution_list))
+        return [int(s) for s in solution_list if isinstance(s, str) and len(s)>0]
     def get_species(self, solution):
         return self._get_species(self.id_, solution).decode('utf-8').split(",")
     def get_si(self, solution, phase):
@@ -459,6 +463,8 @@ class VIPhreeqc(object):
     def load_database(self, database_name):
         """Load a database with given file_name.
         """
+        # ensure string
+        database_name = str(database_name)
         self.phc_database_error_count = self._load_database(
             self.id_, bytes(database_name, 'utf-8'))
 
@@ -477,7 +483,7 @@ class VIPhreeqc(object):
     def run_string(self, cmd_string):
         """Run PHREEQC input from string.
         """
-        #print(cmd_string)
+        # print(cmd_string)
         if self.debug:
             print(cmd_string)
 
